@@ -1140,7 +1140,7 @@ public class Master extends AccumuloServerContext
         } catch (TException e) {
           log.error("{}", e.getMessage(), e);
         }
-        tserverSet.remove(instance);
+        badServers.putIfAbsent(instance, new AtomicInteger(1));
       }
     }
 
